---
title: Cell
description: Represents a cell in the world.
---

## Attributes

| Attribute | Type | Description                         |
|-----------|------|-------------------------------------|
| `agent_id_list` | `list[AgentID]` | List of agent IDs present in the cell. |
| `move_cost` | `int` | The movement cost associated with the cell. |
| `location` | `Location` | The location of the cell on the map. |

